sudo cp SquidAnalyzer.pm /usr/share/perl5/SquidAnalyzer.pm
sudo rm -rf /var/www/squidanalyzer/index.html 
sudo rm -rf /var/www/squidanalyzer/2013/
sudo rm -rf /var/www/squidanalyzer/SquidAnalyzer.current 
